-- VNurse.ddl
-- DDL file for creating tables and populating data for "Visiting Nurse" application on    server side

-- SQL statement to CREATE DATABASE
-- database name "VNURSE" can translated
-- if translated it should correspond to the sample database name in other ddl files 

CREATE DATABASE VNURSE;

-- SQL statement to increase heap size

UPDATE DB CONFIG FOR VNURSE USING APPLHEAPSZ 512;

-- SQL statement to CONNECT to database "VNURSE"
 
CONNECT TO VNURSE;

-- SQL statement to create sample schema
-- New change
 
CREATE SCHEMA DSYSAMPLE;

--- SQL statement to CREATE tables
--- table names "VNPerson", "VNMedicalRecord", "VNContact", and "VNSchedule"
--- can be translated
--- "ID", "Name", "Address", "City", "HomePhone", "WorkPhone", and "MobilePhone"
--- are the column names of table "VNPerson", and can be translated
--- "DSYSAMPLE" IS NEW BUT SHOULD NOT BE TRANSLATED!!

CREATE TABLE DSYSAMPLE.VNPerson (ID Char(9) not null PRIMARY KEY, Name Varchar(40), Address Varchar(50), City Varchar(25), HomePhone Varchar(20), WorkPhone Varchar(20), MobilePhone Varchar(20));


--- "RecordID", "Date_C", "Time_C", "PatientID", "BloodPressure", "PulseRate", "Temperature", 
--- "Weight", and "Comment" are column names of the table "VNMedicalRecord", and can be translated

CREATE TABLE DSYSAMPLE.VNMedicalRecord (RecordID Integer not null PRIMARY KEY, Date_C Date, Time_C Time, PatientID Varchar(9), BloodPressure Char(7), PulseRate Smallint, Temperature Decimal(4,1), Weight Decimal(5,2), Comment Varchar(100));


--- "PatientID", "ContactID", and "Relationship" are column names of the table "VNContact"
--- and can be translated

CREATE TABLE DSYSAMPLE.VNContact (PatientID Char(9) not null, ContactID Char(9) not null, Relationship Varchar(10), Primary Key (PatientID, ContactID));


--- "PatientID", "Time_C" are column names of table "VNSchedule", and can be translated

CREATE TABLE DSYSAMPLE.VNSchedule (PatientID Varchar(9), Time_C Time not null PRIMARY KEY);



--- New for translation
--- "RecordID", "NurseName" and "Signature" are columns of table "VNSignature" and can be --- translated 

CREATE TABLE DSYSAMPLE.VNSignature (RecordID Integer not null PRIMARY KEY, NurseName Varchar(40), Signature long varchar for bit data); 


---- SQL statement to INSERT data into VNPerson table
-- Patients

--- Example translatable values for "VNPerson" table
---- ', ' is the name of a patient limited to 40 characters
---- '  1' is an "Address" limited to 50 charaters
---- '  44333' is a "City" limited to 25 characters
---- '(08)783-4946' is a "HomePhone" limited to 20 characters
---- '(08)749-7506' is a "WorkPhone" limited to 20 characters
---- '(08)442-3030' is a "MobilePhone"  limited to 20 characters

INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000001',	', ',	  	    '  1', 			      '  44333',      '(08)783-4946', '(08)749-7506', '(08)442-3030');


INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000101',	', ',	    '.. 292', 		        '  19055',    '(03)945-9168', '(03)664-0900', '(03)305-2591');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000201',	', ', 		'  5',		    ' 75954',      '(03)269-1655',	'(03)269-7410', '(03)305-6359');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000301',	', ', 	  	    '  55',		  ' 44653',      '(04)339-0537',	'(04)269-1548', '(04)898-6483');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000401',	', ', 		'  41',		    '  90061',  '(03)755-4041',	'(03)945-3602', '(03)265-4350');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000501',	', ', 		    '  12',	    ' 26354',      '(08)265-0836',	'(08)254-9374', '(08)897-1020');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000601',	', ', 	'.. 13',			        ' 29541',    '(08)665-4021',	'(08)664-7348', '(08)894-3199');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000701',	'  ', 	  	  '  21',		  ' 54568',     '(04)358-4484',	'(04)227-8281', '(04)339-4734');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000801',	', ', 		'  17',		    ' 23517',      '(09)622-1999',	'(09)945-6418', '(09)476-7938');

-- Other VNPersons
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000901',	', ', '  4',			    ' 29541',    '(03)665-3788',	'(03)476-8127', '(03)339-0467');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001001',	', ', 		'  53',	  '  99026',   '(03)467-4893',	'(03)567-4648', '(03)764-2483');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001101',	' , ', 		  '  5',		    '55054',   '(03)461-2421',	'(03)567-4310', '(03)575-6617');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001201',	', ', 	  	'  76',  '  43204',     '(09)274-9514',	'(09)476-4309', '(09)254-7616');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001301',	', ',	  	    '  17',		    ' 14098',  '(03)765-2082',	'(03)898-2929', '(03)945-6541');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001401',	' , ', 	  '   66',	' 23517',      '(09)622-1840',	'(09)231-4966', '(09)765-7376');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001501',	' , ', 	  	  '   19',	    ' 08037',    '(08)567-9741',	'(08)837-7529', '(08)381-0778');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001601',	', ', 	  	'  65 ',		    ' 65652',     '(09)738-4604',	'(09)381-3902', '(09)274-0153');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001701',	', ', 	  	  '  7 ',		  '  33953',    '(03)764-3035',	'(03)567-2190', '(03)305-1842');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001801',	', ', 	  	      '  3',			    ' 48708',     '(03)894-5724',	'(03)665-1478', '(03)765-9358');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001901',	', ', 		    '  2',  ' 21212',    '(04)435-6729',	'(04)837-4370', '(04)476-5350');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900002001',	', ',	  '  23',		  '  77437',     '(03)543-6827',	'(03)461-9961', '(03)242-0491');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900002101',	', ', 		  '  69',	  ' 93311',  '(02)664-2382',	'(02)374-7421', '(02)533-8716');

---- SQL statement to INSERT data into VNContact table
-- For patient 900000001


--- Example translatable values for the "VNContact" table
---- '' is a "Relationship" limited to 10 characters

INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001201',	'');


INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001101',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001001',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900000901',	'');

-- For patient 900000101
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001501',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001301',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001401',	'');

-- For patient 900000201
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001701',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001601',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001801',	'');

-- For patient 900000301
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900001901',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900002101',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900002001',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900001201',	'');

-- For patient 900000401
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900001101',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900001401',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900000701',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900002101',	'');

-- For patient 900000501
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001801',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001001',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001201',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001101',	'');

-- For patient 900000601
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001301',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001501',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001701',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001901',	'');

-- For patient 900000701
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001101',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001001',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001201',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001501',	'');

-- For patient 900000801
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001101',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001901',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001401',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001701',	'');


---- SQL statement to INSERT data into VNSchedule table

INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000001',	'08:00:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000701',	'08:45:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000101',	'10:00:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000801',	'11:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000201',	'11:45:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000401',	'14:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000501',	'15:30:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000601',	'16:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000301',	'17:00:00');

---- SQL statement to INSERT data into Medical Record table

--- Example translatable values for the "VNMedicalRecord" table
---- '160/95' is the blood pressure (systolic/diastolic) (are the units the same everywhere?) 
---- 80 is the pulse rate
---- 104.2 is the temperature in degress Farenheit
---- 150.5 is the weight in pounds (lbs.)
---- ' .   .' is a comment, limited to 100 characters

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (1,	  '1999-07-20',	'09:10:00',	'900000001',	'160/95',	80,	104.2,	150.5,  ' .   .');


INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (2,	  '1999-07-19',	'19:53:00',	'900000001',	'155/90',	72,	100.5, 	154.5,	'    .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (3,	  '2000-06-13',	'18:42:00',	'900000001',	'130/80',	65,	100.2,	170,	  '   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (4,	  '2000-05-07',	'17:54:00',	'900000001',	'140/83',	68,	101,	  175.2,  '   ');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (5,	  '2000-04-14',	'14:56:00',	'900000101',	'130/84',	59,	99.4,	  192,	  '    .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (6,	  '2000-03-15',	'12:49:00',	'900000101',	'120/85',	60,	103,	  192,	  '   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (7,	  '1999-02-07',	'01:02:00',	'900000101',	'115/86',	51,	102.8,	189,	  '   .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (8,	  '1999-07-15',	'11:02:00',	'900000201',	'135/87',	73,	104.2,	169,	  '      .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (9,	  '1999-07-13',	'11:47:00',	'900000201',	'180/98',	70,	100.7,	174,	  '     .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (10,	'1999-06-08',	'01:17:00',	'900000301',	'200/99',	55,	99,		  148,	  '    .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (11,	'1999-05-12',	'16:40:00',	'900000301',	'175/80',	56,	99.6,	  154,		'   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (12,	'2000-04-19',	'00:11:00',	'900000301',	'166/81',	51,	106,		145,	  ' .   .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (13,	'2000-03-19',	'03:38:00',	'900000401',	'175/82',	76,	98.6,   117,	  ' .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (14,	'2000-02-17',	'09:04:00',	'900000401',	'152/83',	65,	98,		  115,	  '   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (15,	'2000-01-20',	'00:50:00',	'900000401',	'132/84',	72,	98,		  110.2,	'   .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (16,	'1999-08-08',	'03:25:00',	'900000501',	'174/85',	72,	98,		  171.2,	'.');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (17,	'1999-07-08',	'11:31:00',	'900000501',	'165/86',	69,	97.9,	  171,	  '   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (18,	'1999-06-04',	'13:44:00',	'900000501',	'180/87',	68,	98.2,	  181,	  '   .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (19,	'2000-05-04',	'02:46:00',	'900000601',	'110/88',	77,	98.4,	  250,	  '');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (20,	'1999-04-22',	'02:03:00',	'900000601',	'175/89',	60,	105,	  245,	  ' ,    .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (21,	'2000-03-04',	'04:46:00',	'900000701',	'183/90',	51,	99,		  182,	  '  .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (22,	'2000-02-16',	'19:20:00',	'900000701',	'107/91',	60,	99.5,	  175,	  '   .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (23,	'1999-01-23',	'15:47:00',	'900000701',	'122/92',	54,	100,	  178,	  '   .');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (24,	'2000-07-20',	'11:37:00',	'900000801',	'162/93',	73,	104.5,  130,	  ' .      .');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (25,	'1999-07-06',	'17:16:00',	'900000801',	'163/94',	51,	101.9,  127,	  '      .');

COMMIT;
CONNECT RESET;

-- SQL statement to create mirror database
-- "M_VNURSE" can be translated
-- if translated it should correspond to the mirror database name in other ddl files
-- New change


CREATE DATABASE M_VNURSE;
UPDATE DB CONFIG FOR M_VNURSE USING APPLHEAPSZ 512;

-- New for translation
-- SQL statement to create mirror database for jdbc subscription
-- "M_VN2" can be translated

CREATE DATABASE M_VN2;
UPDATE DB CONFIG FOR M_VN2 USING APPLHEAPSZ 512;



