-- VNurse.ddl
-- DDL file for creating tables and populating data for "Visiting Nurse" application on    server side

-- SQL statement to CREATE DATABASE
-- database name "VNURSE" can translated
-- if translated it should correspond to the sample database name in other ddl files 

CREATE DATABASE VNURSE;

-- SQL statement to increase heap size

UPDATE DB CONFIG FOR VNURSE USING APPLHEAPSZ 512;

-- SQL statement to CONNECT to database "VNURSE"
 
CONNECT TO VNURSE;

-- SQL statement to create sample schema
-- New change
 
CREATE SCHEMA DSYSAMPLE;

--- SQL statement to CREATE tables
--- table names "VNPerson", "VNMedicalRecord", "VNContact", and "VNSchedule"
--- can be translated
--- "ID", "Name", "Address", "City", "HomePhone", "WorkPhone", and "MobilePhone"
--- are the column names of table "VNPerson", and can be translated
--- "DSYSAMPLE" IS NEW BUT SHOULD NOT BE TRANSLATED!!

CREATE TABLE DSYSAMPLE.VNPerson (ID Char(9) not null PRIMARY KEY, Name Varchar(40), Address Varchar(50), City Varchar(25), HomePhone Varchar(20), WorkPhone Varchar(20), MobilePhone Varchar(20));


--- "RecordID", "Date_C", "Time_C", "PatientID", "BloodPressure", "PulseRate", "Temperature", 
--- "Weight", and "Comment" are column names of the table "VNMedicalRecord", and can be translated

CREATE TABLE DSYSAMPLE.VNMedicalRecord (RecordID Integer not null PRIMARY KEY, Date_C Date, Time_C Time, PatientID Varchar(9), BloodPressure Char(7), PulseRate Smallint, Temperature Decimal(4,1), Weight Decimal(5,2), Comment Varchar(100));


--- "PatientID", "ContactID", and "Relationship" are column names of the table "VNContact"
--- and can be translated

CREATE TABLE DSYSAMPLE.VNContact (PatientID Char(9) not null, ContactID Char(9) not null, Relationship Varchar(10), Primary Key (PatientID, ContactID));


--- "PatientID", "Time_C" are column names of table "VNSchedule", and can be translated

CREATE TABLE DSYSAMPLE.VNSchedule (PatientID Varchar(9), Time_C Time not null PRIMARY KEY);



--- New for translation
--- "RecordID", "NurseName" and "Signature" are columns of table "VNSignature" and can be --- translated 

CREATE TABLE DSYSAMPLE.VNSignature (RecordID Integer not null PRIMARY KEY, NurseName Varchar(40), Signature long varchar for bit data); 


---- SQL statement to INSERT data into VNPerson table
-- Patients

--- Example translatable values for "VNPerson" table
---- 'ؑY' is the name of a patient limited to 40 characters
---- 'ʂl1-18' is an "Address" limited to 50 charaters
---- 'Fs{s' is a "City" limited to 25 characters
---- '(202)783-4946' is a "HomePhone" limited to 20 characters
---- '(202)749-7506' is a "WorkPhone" limited to 20 characters
---- '(202)442-3030' is a "MobilePhone"  limited to 20 characters

INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000001',	'ؑY',	  	    'ʂl1-18', 			      'Fs{s',      '(202)783-4946', '(202)749-7506', '(202)442-3030');


INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000101',	'т͂',	    'V񒚖4-2', 		        '`',    '(215)945-9168', '(215)664-0900', '(215)305-2591');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000201',	'ѓcTg', 		'tԒl6-1',		    'ߔes',      '(409)269-1655',	'(409)269-7410', '(409)305-6359');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000301',	'gc', 	  	    'A8-2',		  'Os',      '(216)339-0537',	'(216)269-1548', '(216)898-6483');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000401',	'؈v', 		'˔3-5',		    'ێs',  '(213)755-4041',	'(213)945-3602', '(213)265-4350');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000501',	'됰', 		    'ɐ{519-1',	    ']s',      '(304)265-0836',	'(304)254-9374', '(304)897-1020');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000601',	'㔪q', 	'kK꒚11-15',			        'Dys',    '(803)665-4021',	'(803)664-7348', '(803)894-3199');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000701',	'ēcǕ', 	  	  '񒚖2-3',		  's',     '(715)358-4484',	'(715)227-8281', '(715)339-4734');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000801',	'됰', 		'񒚖9-21',		    'Os',      '(804)622-1999',	'(804)945-6418', '(804)476-7938');

-- Other VNPersons
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900000901',	'ؑg', 'k܏𐼘Z2',			    'Dys',    '(803)665-3788',	'(803)476-8127', '(803)339-0467');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001001',	'뎟', 		'lʎڍ6',	  's',   '(509)467-4893',	'(509)567-4648', '(509)764-2483');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001101',	'ēck', 		  'tԒl6-1',		    's',   '(612)461-2421',	'(612)567-4310', '(612)575-6617');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001201',	'cǏ', 	  	'wO񒚖10-16',  'SRs',     '(614)274-9514',	'(614)476-4309', '(614)254-7616');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001301',	'ǔV',	  	    '񒚖9-21',		    'b{s',  '(716)765-2082',	'(716)898-2929', '(716)945-6541');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001401',	'q', 	  'Ė{1-1',	'Os',      '(804)622-1840',	'(804)231-4966', '(804)765-7376');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001501',	'J쎟Y', 	  	  '꒚73',	    'Js',    '(609)567-9741',	'(609)837-7529', '(609)381-0778');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001601',	'ѓc~q', 	  	'l1-16',		    '_s',     '(417)738-4604',	'(417)381-3902', '(417)274-0153');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001701',	'㔪q', 	  	  'LO1-1',		  's',    '(941)764-3035',	'(941)567-2190', '(941)305-1842');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001801',	'ԓcq', 	  	      '㒬O5-4',			    's',     '(517)894-5724',	'(517)665-1478', '(517)765-9358');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900001901',	'xc', 		    'k擯l񒚖2-8',  's',    '(410)435-6729',	'(410)837-4370', '(410)476-5350');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900002001',	'c',	  '掺ʌr~338',		  's{',     '(409)543-6827',	'(409)461-9961', '(409)242-0491');
INSERT INTO DSYSAMPLE.VNPerson VALUES ('900002101',	'c', 		  '攎wOO23-22',	  's',  '(805)664-2382',	'(805)374-7421', '(805)533-8716');

---- SQL statement to INSERT data into VNContact table
-- For patient 900000001


--- Example translatable values for the "VNContact" table
---- 'Fl' is a "Relationship" limited to 10 characters

INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001201',	'Fl');


INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001101',	'i');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900001001',	'Z');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000001',	'900000901',	'Fl');

-- For patient 900000101
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001501',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001301',	'f');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000101',	'900001401',	'Z');

-- For patient 900000201
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001701',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001601',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000201',	'900001801',	'`');

-- For patient 900000301
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900001901',	'Fl');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900002101',	'i');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900002001',	'Z');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000301',	'900001201',	'Z');

-- For patient 900000401
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900001101',	'Fl');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900001401',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900000701',	'i');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000401',	'900002101',	'Fl');

-- For patient 900000501
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001801',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001001',	'Z');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001201',	'Fl');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000501',	'900001101',	'Fl');

-- For patient 900000601
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001301',	'`');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001501',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001701',	'f');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000601',	'900001901',	'f');

-- For patient 900000701
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001101',	'Z');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001001',	'i');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001201',	'Fl');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000701',	'900001501',	'');

-- For patient 900000801
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001101',	'Z');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001901',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001401',	'');
INSERT INTO DSYSAMPLE.VNContact VALUES ('900000801',	'900001701',	'f');


---- SQL statement to INSERT data into VNSchedule table

INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000001',	'08:00:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000701',	'08:45:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000101',	'10:00:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000801',	'11:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000201',	'11:45:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000401',	'14:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000501',	'15:30:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000601',	'16:15:00');
INSERT INTO DSYSAMPLE.VNSchedule VALUES ('900000301',	'17:00:00');

---- SQL statement to INSERT data into Medical Record table

--- Example translatable values for the "VNMedicalRecord" table
---- '160/95' is the blood pressure (systolic/diastolic) (are the units the same everywhere?) 
---- 80 is the pulse rate
---- 104.2 is the temperature in degress Farenheit
---- 150.5 is the weight in pounds (lbs.)
---- '110 Ԃ܂Ba@`FbN܂B' is a comment, limited to 100 characters

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (1,	  '1999-07-20',	'09:10:00',	'900000001',	'160/95',	80,	104.2,	150.5,  '110 Ԃ܂Ba@`FbN܂B');


INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (2,	  '1999-07-19',	'19:53:00',	'900000001',	'155/90',	72,	100.5, 	154.5,	'͂Ȓɍ܂𓊗^B');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (3,	  '2000-06-13',	'18:42:00',	'900000001',	'130/80',	65,	100.2,	170,	  'ƎdxŁA̋x{ƂKvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (4,	  '2000-05-07',	'17:54:00',	'900000001',	'140/83',	68,	101,	  175.2,  'HÖ@vAhoCX܂');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (5,	  '2000-04-14',	'14:56:00',	'900000101',	'130/84',	59,	99.4,	  192,	  'TAtYŌ삪KvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (6,	  '2000-03-15',	'12:49:00',	'900000101',	'120/85',	60,	103,	  192,	  'AtYŌ삪KvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (7,	  '1999-02-07',	'01:02:00',	'900000101',	'115/86',	51,	102.8,	189,	  'łѕсB');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (8,	  '1999-07-15',	'11:02:00',	'900000201',	'135/87',	73,	104.2,	169,	  '[Ō󂯂邽߂ɓ@ÓB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (9,	  '1999-07-13',	'11:47:00',	'900000201',	'180/98',	70,	100.7,	174,	  'eԂ͏܂܂ÂKvB');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (10,	'1999-06-08',	'01:17:00',	'900000301',	'200/99',	55,	99,		  148,	  'ɖ^B');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (11,	'1999-05-12',	'16:40:00',	'900000301',	'175/80',	56,	99.6,	  154,		'ƎdxŁA̋x{ƂKvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (12,	'2000-04-19',	'00:11:00',	'900000301',	'166/81',	51,	106,		145,	  '110 Ԃ܂Ba@`FbN܂B');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (13,	'2000-03-19',	'03:38:00',	'900000401',	'175/82',	76,	98.6,   117,	  'ύX_͂ȂB ');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (14,	'2000-02-17',	'09:04:00',	'900000401',	'152/83',	65,	98,		  115,	  'ƎdxŁA̋x{ƂKvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (15,	'2000-01-20',	'00:50:00',	'900000401',	'132/84',	72,	98,		  110.2,	'ƎdxŁA̋x{ƂKvB');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (16,	'1999-08-08',	'03:25:00',	'900000501',	'174/85',	72,	98,		  171.2,	'NłB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (17,	'1999-07-08',	'11:31:00',	'900000501',	'165/86',	69,	97.9,	  171,	  'Pɕ');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (18,	'1999-06-04',	'13:44:00',	'900000501',	'180/87',	68,	98.2,	  181,	  '܂wɕсB');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (19,	'2000-05-04',	'02:46:00',	'900000601',	'110/88',	77,	98.4,	  250,	  'OK');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (20,	'1999-04-22',	'02:03:00',	'900000601',	'175/89',	60,	105,	  245,	  'Ǐ󂪏d̂œ@߂܂');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (21,	'2000-03-04',	'04:46:00',	'900000701',	'183/90',	51,	99,		  182,	  'bB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (22,	'2000-02-16',	'19:20:00',	'900000701',	'107/91',	60,	99.5,	  175,	  'ƎdxŁA̋x{ƂKvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (23,	'1999-01-23',	'15:47:00',	'900000701',	'122/92',	54,	100,	  178,	  'ƎdxŁA̋x{ƂKvB');

INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (24,	'2000-07-20',	'11:37:00',	'900000801',	'162/93',	73,	104.5,  130,	  'ΈÁAߐe҂֘AKvB');
INSERT INTO DSYSAMPLE.VNMedicalRecord VALUES (25,	'1999-07-06',	'17:16:00',	'900000801',	'163/94',	51,	101.9,  127,	  '[Ō󂯂邽߂ɓ@ÓB');

COMMIT;
CONNECT RESET;

-- SQL statement to create mirror database
-- "M_VNURSE" can be translated
-- if translated it should correspond to the mirror database name in other ddl files
-- New change


CREATE DATABASE M_VNURSE;
UPDATE DB CONFIG FOR M_VNURSE USING APPLHEAPSZ 512;

-- New for translation
-- SQL statement to create mirror database for jdbc subscription
-- "M_VN2" can be translated

CREATE DATABASE M_VN2;
UPDATE DB CONFIG FOR M_VN2 USING APPLHEAPSZ 512;




