-------------------------------------------------------------------------
-- (C) COPYRIGHT International Business Machines Corp. 2000-2001
-- All Rights Reserved
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--
-- dsyctldb.ddl: DB2 Everyplace Mobile Devices Control Database SQL.
-------------------------------------------------------------------------

--* Create database DSYCTLDB
create database DSYCTLDB;

--* Connect to database DSYCTLDB
connect to DSYCTLDB;

--* Update database DSYCTLDB performance parameters
update db config for dsyctldb using applheapsz 1024;
update db config for dsyctldb using logfilsiz 1024;
update db config for dsyctldb using logprimary 5;
update db config for dsyctldb using logsecond 5;

--* Create schema DSY (if does not exist)
create schema DSY;

--* Create table DSY.GROUPS (if does not exist)
create table
  DSY.GROUPS(
    ID char(13) for bit data primary key not null,
    NAME varchar(18) unique not null,
    DESCRIPTION varchar(128),
    PASSWORD varchar(18),
    ENABLED char(1) not null with default 'N',
    constraint CK_ENABLED check(ENABLED in('N','Y'))
  );

--* Create table DSY.CLIENTS (if does not exist)
create table
  DSY.CLIENTS(
    GROUP_ID char(13) for bit data,
    ID char(13) for bit data primary key not null,
    NAME varchar(18) unique not null,
    DESCRIPTION varchar(128),
    PASSWORD varchar(18),
		 KEY8 char(8) not null with default '00000000',
		 KEY16 char(16) not null with default '0000000000000000',
		 KEY24 char(24) not null with default '000000000000000000000000',
    KEYDIRTY char(1) not null with default 'Y',
		 NEXTNONCE varchar(16),
    constraint FK_GROUP_ID foreign key(GROUP_ID) references DSY.GROUPS(ID) on delete set null,
    constraint CK_KEYDIRTY check(KEYDIRTY in('N','Y'))
  );
alter table DSY.CLIENTS add column KEY8 char(8) not null with default '00000000';
alter table DSY.CLIENTS add column KEY16 char(16) not null with default '0000000000000000';
alter table DSY.CLIENTS add column KEY24 char(24) not null with default '000000000000000000000000';
alter table DSY.CLIENTS add column KEYDIRTY char(1) not null with default 'Y';
alter table DSY.CLIENTS add column NEXTNONCE varchar(16);
alter table DSY.CLIENTS add constraint CK_KEYDIRTY check(KEYDIRTY in('N','Y'));

--* Create table DSY.DEVICES (if does not exist)
create table
  DSY.DEVICES(
    CLIENT_ID char(13) for bit data unique not null,
    ID varchar(32) not null,
    TYPE varchar(4) not null,
    ENABLED char(1) not null with default 'N',
    DIRTY char(1) not null with default 'Y',
--*    STATUS_CODE integer with default 0,
--*    STATUS_TIMESTAMP timestamp,
    constraint FK_CLIENT_ID foreign key(CLIENT_ID) references DSY.CLIENTS(ID) on delete cascade,
    constraint UN_IDTYPE unique (ID,TYPE),
    constraint CK_ENABLED check(ENABLED in('N','Y')),
    constraint CK_DIRTY check(DIRTY in('N','Y'))
  );

--* Create table DSY.APPLICATIONS (if does not exist)
create table
  DSY.APPLICATIONS(
    ID char(13) for bit data primary key not null,
    NAME varchar(18) unique not null,
    DESCRIPTION varchar(128),
    SIGNATURE varchar(18)
  );

--* Create table DSY.GROUP_APPLICATIONS (if does not exist)
-- no primary key as id's can exist many times
create table
  DSY.GROUP_APPLICATIONS(
    GROUP_ID char(13) for bit data not null,
    APPLICATION_ID  char(13) for bit data not null,
		 ORDER integer with default 0,
    constraint UN_GROUP_APPL unique (GROUP_ID,APPLICATION_ID),
    constraint FK_GROUP_ID foreign key(GROUP_ID) references DSY.GROUPS(ID) on delete cascade,
    constraint FK_APPLICATION_ID foreign key(APPLICATION_ID) references DSY.APPLICATIONS(ID) on delete cascade
  );
--*   Migrate to v7.2.1 (if not migrated)
alter table DSY.GROUP_APPLICATIONS add column ORDER integer with default 0;

--* Create table DSY.ADAPTERS (if does not exist)
create table
  DSY.ADAPTERS(
    ID char(13) for bit data primary key not null,
    NAME varchar(18) unique not null,
    DESCRIPTION varchar(128),
    FILE_ATTRIBUTES varchar(512),
    COMM_ATTRIBUTES varchar(512),
    SIGNATURE varchar(18),
    CLASSNAME varchar(512)
  );
alter table DSY.ADAPTERS add column CLASSNAME varchar(512);

--*   Insert default adapters (if do not exist)
insert into dsy.adapters(id, name, description, signature)
  values(x'00000000000000000000000000', 'DSYFILE',  'Default DB2 Everyplace File adapter',  'DSYFILE');
insert into dsy.adapters(id, name, description, signature)
  values(x'00000000000000000000000001', 'DSYDPROPR', 'Default DB2 Everyplace DataPropagator adapter', 'DSYDPROPR');
insert into dsy.adapters(id, name, description, signature)
  values(x'00000000000000000000000002', 'DSYJDBC', 'Default DB2 Everyplace JDBC adapter', 'DSYJDBC');
insert into dsy.adapters(id, name, description, signature)
  values(x'00000000000000000000000003', 'DSYPIM', 'Default DB2 Everyplace PIM adapter', 'DSYPIM');
insert into dsy.adapters(id, name, description, file_attributes, comm_attributes, signature, classname)
  values(GENERATE_UNIQUE(), 'Agent Adapter', 'Default DB2 Everyplace Agent Adapter', 'libname=agent.dll', 'cmd=/servlet/com.ibm.mobileservices.adapter.agent;dest=127.0.0.1:8080;', 'DSYAGENT', 'AgentAdapter.class');
--*   Migrate to v7.1.1 (if not migrated)
update dsy.adapters set name='DSYDPROPR' where name='DSYTABLE';
update dsy.adapters set signature='DSYDPROPR' where name='DSYDPROPR';
update dsy.adapters set description='Default DB2 Everyplace DataPropagator adapter' where name='DSYDPROPR';

--* Create table DSY.SUBSCRIPTIONS (if does not exist)
create table
  DSY.SUBSCRIPTIONS(
    ID char(13) for bit data primary key not null,
    NAME varchar(18) unique not null,
    DESCRIPTION varchar(128),
    ADAPTER_ID char(13) for bit data,
    TIMESTAMP timestamp with default current timestamp,
		 ENCRYPTION_LEVEL integer with default 0,
    constraint FK_ADAPTER_ID foreign key(ADAPTER_ID) references DSY.ADAPTERS(ID) on delete set null
  );
alter table DSY.SUBSCRIPTIONS add column ENCRYPTION_LEVEL integer with default 0;

--* Create table DSY.APPLICATION_SUBS (if does not exist)
create table
  DSY.APPLICATION_SUBS(
    APPLICATION_ID char(13) for bit data not null,
    SUBSCRIPTION_ID char(13) for bit data not null,
		 ORDER integer with default 0,
    constraint UN_APPL_SUB unique (APPLICATION_ID,SUBSCRIPTION_ID),
    constraint FK_APPLICATION_ID foreign key(APPLICATION_ID) references DSY.APPLICATIONS(ID) on delete cascade,
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade
  );
--*   Migrate to v7.2.1 (if not migrated)
alter table DSY.APPLICATION_SUBS add column ORDER integer with default 0;

--* Create table DSY.FILE_SUBSCRIPTIONS (if does not exist)
create table
  DSY.FILE_SUBSCRIPTIONS(
    SUBSCRIPTION_ID char(13) for bit data primary key not null,
    SOURCE varchar(255) not null,
    TARGET varchar(255),
    DIRTY char(1) not null with default 'Y',
    REFRESH_TIMESTAMP timestamp,
    constraint CK_DIRTY check(DIRTY in('N','Y')),
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade
  );

--* Create table DSY.PIM_SUBSCRIPTIONS (if does not exist)
create table
  DSY.PIM_SUBSCRIPTIONS(
    SUBSCRIPTION_ID char(13) for bit data primary key not null,
    TYPE char(1) not null with default '0',
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade
  );

--* Create table DSY.PIM_SUBSCRIPTION_SERVERS (if does not exist)
-- no primary key as id's can exist many times
create table
  DSY.PIM_SUBSCRIPTION_SERVERS(
    SUBSCRIPTION_ID char(13) for bit data not null,
    SERVER_ID char(13) for bit data not null,
    constraint UN_SUB_SERV unique (SUBSCRIPTION_ID,SERVER_ID),
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade
  );

--* Create table DSY.REPL_MASTER (if does not exist)
create table
  DSY.REPL_MASTER(
    ID char(13) for bit data primary key not null,
    SYSTEM varchar(128) not null,
    INSTANCE varchar(8) not null,
    DATABASE varchar(18) not null,
    USERID varchar(128) not null,
    PASSWORD varchar(128) not null,
		 DATABASEALIAS varchar(18),
    constraint UN_SID unique (SYSTEM,INSTANCE,DATABASE)
  );
alter table DSY.REPL_MASTER add column DATABASEALIAS varchar(18);

--* Create table DSY.REPL_MIRROR (if does not exist)
create table
  DSY.REPL_MIRROR(
    ID char(13) for bit data primary key not null,
    DATABASE varchar(18) not null,
    USERID varchar(128) not null,
    PASSWORD varchar(128) not null,
    SYNC_WINDOW integer with default 3600,
    SYNC_MAX_CLIENTS integer with default 10,
    constraint UN_DATABASE unique (DATABASE)
  );

--* Create table DSY.REPL_SUBSCRIPTIONS (if does not exist)
create table
  DSY.REPL_SUBSCRIPTIONS(
    SUBSCRIPTION_ID char(13) for bit data primary key not null,
    REPL_MASTER_ID char(13) for bit data not null,
    REPL_MIRROR_ID char(13) for bit data not null,
    TARGET_DATABASE varchar(18),
    APPLY_QUALIFIER char(18) not null,
    MIRROR_ONLY char(1) not null with default 'N',
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade,
    constraint FK_REPL_MSTR_ID foreign key(REPL_MASTER_ID) references DSY.REPL_MASTER(ID) on delete cascade,
    constraint FK_REPL_MIRR_ID foreign key(REPL_MIRROR_ID) references DSY.REPL_MIRROR(ID) on delete cascade,
    constraint CK_MIRRORONLY check(MIRROR_ONLY in('N','Y'))
  );

--* Create table DSY.REPL_SUB_TABLES (if does not exist)
create table
  DSY.REPL_SUB_TABLES(
    SUBSCRIPTION_ID char(13) for bit data not null,
    SOURCE_SCHEMA varchar(128) not null,
    SOURCE_TABLE varchar(128) not null,
    TARGET_SCHEMA varchar(128) not null,
    TARGET_TABLE varchar(128) not null,
    DELETEAUTH char(1) not null with default 'Y',
    INSERTAUTH char(1) not null with default 'Y',
    UPDATEAUTH char(1) not null with default 'Y',
    WHERE_CLAUSE varchar(1024),
    SELECTAUTH char(1) not null with default 'Y',
    ID char(13) for bit data,
    WHERE_CLAUSE2 varchar(1024),
		 ORDER integer with default 0,
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade,
    constraint UN_SUB_TBNAME unique (SUBSCRIPTION_ID,TARGET_SCHEMA,TARGET_TABLE),
    constraint CK_DELETEAUTH check(DELETEAUTH in('N','Y')),
    constraint CK_INSERTAUTH check(INSERTAUTH in('N','Y')),
    constraint CK_UPDATEAUTH check(UPDATEAUTH in('N','Y')),
    constraint CK_SELECTAUTH check(SELECTAUTH in('N','Y'))
  );
--*   Migrate to v7.1.1 (if not migrated)
alter table DSY.REPL_SUB_TABLES add column SELECTAUTH char(1) not null with default 'Y' add constraint CK_SELECTAUTH check(SELECTAUTH in('N','Y'));
alter table DSY.REPL_SUB_TABLES add column ID char(13) for bit data;
update dsy.repl_sub_tables set id=generate_unique() where (id is null);
alter table DSY.REPL_SUB_TABLES add column WHERE_CLAUSE2 varchar(1024);
--*   Migrate to v7.2.1 (if not migrated)
alter table DSY.REPL_SUB_TABLES add column ORDER integer with default 0;

--* Create table DSY.JDBC_MASTER (if does not exist)
create table
  DSY.JDBC_MASTER(
    ID char(13) for bit data primary key not null,
    DATABASE varchar(255) not null,
    DRIVER varchar(255) not null,
    USERID varchar(128) not null,
    PASSWORD varchar(128) not null,
    constraint UN_MASTER unique (DATABASE,DRIVER)
  );

--* Create table DSY.JDBC_MIRROR (if does not exist)
create table
  DSY.JDBC_MIRROR(
    ID char(13) for bit data primary key not null,
    DATABASE varchar(255) not null,
    DRIVER varchar(255) not null,
    USERID varchar(128) not null,
    PASSWORD varchar(128) not null,
    SYNC_WINDOW integer with default 3600,
    SYNC_MAX_CLIENTS integer with default 10,
    constraint UN_MIRROR unique (DATABASE,DRIVER)
  );

--* Create table DSY.JDBC_SUBSCRIPTIONS (if does not exist)
create table
  DSY.JDBC_SUBSCRIPTIONS(
    SUBSCRIPTION_ID char(13) for bit data primary key not null,
    JDBC_MASTER_ID char(13) for bit data not null,
    JDBC_MIRROR_ID char(13) for bit data,
    TARGET_DATABASE varchar(18),
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade,
    constraint FK_JDBC_MSTR_ID foreign key(JDBC_MASTER_ID) references DSY.JDBC_MASTER(ID) on delete cascade
--    constraint FK_JDBC_MIRR_ID foreign key(JDBC_MIRROR_ID) references DSY.JDBC_MIRROR(ID) on delete cascade
  );
--*   Migrate to v7.1.1 (if not migrated)
alter table DSY.JDBC_SUBSCRIPTIONS drop constraint FK_JDBC_MIRR_ID;

--* Create table DSY.RDB_SUB_COLUMNS (if does not exist)
create table
  DSY.RDB_SUB_COLUMNS(
    ID char(13) for bit data primary key not null,
    REPL_SUB_TABLE_ID char(13) for bit data not null,
    SOURCE varchar(512) not null,
    TARGET varchar(128) not null,
    SUBSCRIBE char(1) not null with default 'N',
    REPLICATE char(1) not null with default 'N',
    KEY char(1) not null with default 'N',
    CONSTRNT varchar(1024),
		 DATAFILTER varchar(18),
    constraint UN_RPLIDTRG unique (REPL_SUB_TABLE_ID,TARGET),
    constraint CK_SUBSCRIBE check(SUBSCRIBE in('N','Y')),
    constraint CK_REPLICATE check(REPLICATE in('N','Y')),
    constraint CK_KEY check(KEY in('N','Y'))
--* not unique/primary key constraint FK_REPL_SUB_ID foreign key(REPL_SUB_TABLE_ID) references DSY.REPL_SUB_TABLES(ID) on delete cascade
  );
--* not unique/primary key alter table DSY.RDB_SUB_COLUMNS add constraint FK_REPL_SUB_ID foreign key(REPL_SUB_TABLE_ID) references DSY.REPL_SUB_TABLES(ID) on delete cascade;
--*  Migrate to v7.2 (if not migrated)
drop table DSY.JDBC_SUB_COLUMNS;

--* Create table DSY.RDB_SUB_INDEXES (if does not exist)
create table
  DSY.RDB_SUB_INDEXES(
    REPL_SUB_TABLE_ID char(13) for bit data not null,
    ID char(13) for bit data primary key not null,
		 NAME varchar(18) not null unique,
    COLNAMES varchar(1024) not null
  );

--* Create table DSY.CUSTOM_SUBSCRIPTIONS (if does not exist)
create table
  DSY.CUSTOM_SUBSCRIPTIONS(
    SUBSCRIPTION_ID char(13) for bit data primary key not null,
		 OTHER clob(4096),
    constraint FK_SUBSCRIPTION_ID foreign key(SUBSCRIPTION_ID) references DSY.SUBSCRIPTIONS(ID) on delete cascade
  );

--* Create table DSY.GROUP_PROPERTIES (if does not exist)
create table
  DSY.GROUP_PROPERTIES(
    GROUP_ID char(13) for bit data not null,
    NAME varchar(18) not null,
    VALUE varchar(36),
    constraint UN_GROUP_NAME unique (GROUP_ID,NAME),
    constraint FK_GROUP_ID foreign key(GROUP_ID) references DSY.GROUPS(ID) on delete cascade
  );

--* Create table DSY.CLIENT_PROPERTIES (if does not exist)
create table
  DSY.CLIENT_PROPERTIES(
    CLIENT_ID char(13) for bit data not null,
    NAME varchar(18) not null,
    VALUE varchar(36),
    constraint UN_CLIENT_NAME unique (CLIENT_ID,NAME),
    constraint FK_CLIENT_ID foreign key(CLIENT_ID) references DSY.CLIENTS(ID) on delete cascade
  );

--* Create table DSY.LOG (if does not exist)
create table
  DSY.LOG(
    ID char(13) for bit data primary key not null,
    TIMESTAMP timestamp not null with default current timestamp,
    MSGNUM varchar(8) not null,
    MSGTEXT varchar(512) not null
  );

--* Create table DSY.SESSIONMONITOR (if does not exist)
CREATE TABLE
  DSY.SESSIONMONITOR(
    CLIENT VARCHAR(32) NOT NULL,
    SESSION INT NOT NULL,
    SWVER INT,
    STATE INT NOT NULL,
    DBNAME VARCHAR(18) NOT NULL,
    OP INT NOT NULL,
    LASTMSG INT,
    MIBENUM INT NOT NULL,
    MSGDEFERTIME TIMESTAMP,
    UPDATETIME TIMESTAMP NOT NULL,
    SPECIALACTION INT,
    SUBSCRIPTION_ID CHAR(13) FOR BIT DATA,
    MAXMSGSIZE INT,
    CUMERRORTYPE VARCHAR(40),
    CUMERROR VARCHAR(40),
    CUMERROROP VARCHAR(40),
    PRIMARY KEY (CLIENT, SESSION)
  );

--* Create table DSY.OPENSTAGINGSWVER (if does not exist)
CREATE TABLE
  DSY.OPENSTAGINGSWVER(
    DBNAME VARCHAR(18) NOT NULL PRIMARY KEY,
    SWVER INT NOT NULL,
    STATE INTEGER NOT NULL WITH DEFAULT,
    UPDATETIME TIMESTAMP NOT NULL WITH DEFAULT
  );

--* Create table DSY.TABLESUFFIX (if does not exist)
create table 
  dsy.tablesuffix(
    dbname varchar(18) not null,
    schemaname varchar(128) not null,
    mirrortblname varchar(128) not null,
    suffix char(16), 
    primary key(dbname,schemaname,mirrortblname)
  );
insert into dsy.tablesuffix select dbname,schemaname,mirrortblname,substr(sttblname,3) from dsy.tablemapper;

--* Create table DSY.PROPERTIES (if does not exist)
CREATE TABLE
  DSY.PROPERTIES(
	   NAME varchar(254) NOT NULL PRIMARY KEY,
    VALUE varchar(1024) NOT NULL
  );

--* Drop table DSY.TABLEMAPPER (if it exists)
drop table dsy.tablemapper;

--* Commit changes
commit;

--* Disconnect from database DSYCTLDB
disconnect DSYCTLDB;

--* Finished
