#!/bin/ksh
########################################################################
# (C) COPYRIGHT International Business Machines Corp. 2000-2001
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME:	dsy_was_install.sh
#
# FUNCTION:
#	Install IBM DB2 Everyplace SyncServer into WebSphere 4.0.
#	A valid dsyinstance must already exist.
#
########################################################################

DSY_PWD=$PWD
cd ../../..
. ./language_table.sh
. ./functions_install.sh
. ./functions_install_lang.sh
. ./locations.sh
. ./update_dsy_env_vars.sh

#DEBUG="ON"

##########################################################
#
# Exporting the messages to the environment
#
##########################################################
 
runFileLang "$DSY_LANG_DEFAULT" "install_messages.sh"
# removed because we only support english now
# runFileLang "$SYS_LANG" "install_messages.sh"
 
##########################################################
#
# Check whether this script is being executed as root user
#
##########################################################
 
local u=`whoami`
 
if [ ! "$u" = root ]; then
	echo $MESG_0
	exit 1
fi

##########################################################
#
# Get the node for the WebSphere Application Server
# AdminServer must be running.
#
##########################################################

#
# locate WAS
#
local WAS_HOME
local WSCP="bin/wscp.sh"
local EXEC
if [ -d "/opt/IBMWebAS" ]; then
	WAS_HOME="/opt/IBMWebAS"
elif [ -d "/opt/WebSphere/AppServer" ]; then
	WAS_HOME="/opt/WebSphere/AppServer"
elif [ -d "/usr/WebSphere/AppServer" ]; then
	WAS_HOME="/usr/WebSphere/AppServer"
elif [ -d "/usr/IBMWebAS" ]; then
	WAS_HOME="/usr/IBMWebAS"
else

	echo "$MESG_WAS_Location"
	read WAS_HOME
	checkDir "$WAS_HOME"

fi

EXEC="$WAS_HOME"/"$WSCP"
checkFile "$EXEC"
[ "${DEBUG}" = "ON" ] && echo "Executable: $EXEC"

#
# retrieve list of WAS nodes:
#
echo "$MESG_Retreiving_Available_WAS_Nodes"
local NODES=`echo "Node list" | "$EXEC" \
	| sed 's/wscp>//g' \
	| sed 's/^ //g' | sed 's/ $//g' \
	| sed 's/\///g'| sed 's/{//g' \
	| sed 's/}//g' | sed 's/Node://g'`

local ERROR=`echo "$NODES" | grep "invalid command name \"Node\""`
if [ ! "$ERROR" = "" ]; then
	echo "$NODES"
	echo "$MESG_ERROR_Perhaps_AdminServer_not_running"
	exit	
fi


if [ "$NODES" = "" ]; then

	[ "${DEBUG}" = "ON" ] && echo "Node list" | "$EXEC"

	echo "$MESG_No_Nodes_Error"
	exit

fi
echo $NODES

#
# pick first listed node as default
#
DEF_ADMINNODENAME=`echo "$NODES" | $AWK 'BEGIN{FS=" "}{print $1}'`

echo "$MESG_Enter_WAS_AdminNode [$DEF_ADMINNODENAME]"
read ADMINNODENAME
if [ "$ADMINNODENAME" = "" ]; then
	ADMINNODENAME="$DEF_ADMINNODENAME"
fi

##########################################################
#
# Ask for user to get vars to substitute for XMLConfig
#
##########################################################
../bin/dsyilist

echo "$MESG_4a"
read DB2USERNAME
checkUser "$DB2USERNAME" "$MESG_4a0 ($DB2USERNAME)"

#
# check for home directory of dsyinstance
#
local HOMEDIR=`cat /etc/passwd|$GREP ^$DB2USERNAME|$AWK 'BEGIN{FS=":"}{print $6}'`
if [ ! -d "$HOMEDIR" ]; then

	HOMEDIR=`echo ~${DB2USERNAME}`

	if [ ! -d "$HOMEDIR" ]; then

		echo "$MESG_4d3"
		read HOMEDIR

		if [ ! -d "$HOMEDIR" ]; then

			echo "$MESG_4d2 ($HOMEDIR)"
			exit

		fi
	fi
fi
 
[ "${DEBUG}" = "ON" ] && printMsg "$MSG_Home_dir $HOMEDIR"
 
checkDir "$HOMEDIR" "$MESG_4d2 ($HOMEDIR)"
export DSYSQLLIBINSTDIR="$HOMEDIR/sqllib"
checkDir "$DSYSQLLIBINSTDIR" "$MESG_4d ($DSYSQLLIBINSTDIR)"
checkIfDB2Instance "$DB2USERNAME" "$MESG_4d1 ($DB2USERNAME)"

local DSYINSTDIR=`../bin/dsyilist $DB2USERNAME -di`
local DSYGROUP=`../bin/dsyilist $DB2USERNAME -g`
local DSYSQLLIBINSTDIR="$HOMEDIR"/sqllib


[ "${DEBUG}" = "ON" ] && echo "DSYINSTDIR:$DSYINSTDIR"
[ "${DEBUG}" = "ON" ] && echo "DSYSQLLIBINSTDIR: $DSYSQLLIBINSTDIR"
[ "${DEBUG}" = "ON" ] && echo "GROUP: $DSYGROUP"



##########################################################
#
# Begin installation. 
#
##########################################################

cd "$DSY_PWD"
local XMLCfg="bin/XMLConfig.sh"
local EXEC="$WAS_HOME"/"$XMLCfg"
checkFile "$EXEC"


[ "${DEBUG}" = "ON" ] && echo "Executable: $EXEC"
	
"$EXEC" -adminNodeName $ADMINNODENAME -import ../common/dsy_was40_install.xml  -substitute "DSYINSTDIR=$DSYINSTDIR;DSYSQLLIBINSTDIR=$DSYSQLLIBINSTDIR;dsyuser=$DB2USERNAME;dsygroup=$DSYGROUP;node=$ADMINNODENAME;WAS_ROOT=$WAS_HOME;jdbcdir=java12"
[ "${DEBUG}" = "ON" ] && echo "Update/install server return: $?"

echo "$MESG_SyncServer_Installed_in_WAS"
