#!/bin/ksh
########################################################################
# (C) COPYRIGHT International Business Machines Corp. 2000-2001
# All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# NAME:	dsy_was_install.sh
#
# FUNCTION:
#	Uninstall IBM DB2 Everyplace SyncServer from WebSphere 4.0
#	A valid dsyinstance must already exist.
#
########################################################################

DSY_PWD=$PWD
cd ../../..
. ../install/language_table.sh
. ../install/functions_install.sh
. ../install/functions_install_lang.sh
. ../install/locations.sh
. ../install/update_dsy_env_vars.sh

#DEBUG="ON"

##########################################################
#
# Exporting the messages to the environment
#
##########################################################
 
runFileLang "$DSY_LANG_DEFAULT" "install_messages.sh"
# removed because we only support english now
# runFileLang "$SYS_LANG" "install_messages.sh"
 
##########################################################
#
# Check whether this script is being executed as root user
#
##########################################################
 
local u=`whoami`
 
if [ ! "$u" = root ]; then
	echo $MESG_0
	exit 1
fi

##########################################################
#
# Get the node for the WebSphere Application Server
# AdminServer must be running.
#
##########################################################

#
# locate WAS
#
local WAS_HOME
local WSCP="bin/wscp.sh"
local EXEC
if [ -d "/opt/IBMWebAS" ]; then
	WAS_HOME="/opt/IBMWebAS"
elif [ -d "/opt/WebSphere/AppServer" ]; then
	WAS_HOME="/opt/WebSphere/AppServer"
elif [ -d "/usr/WebSphere/AppServer" ]; then
	WAS_HOME="/usr/WebSphere/AppServer"
elif [ -d "/usr/IBMWebAS" ]; then
	WAS_HOME="/usr/IBMWebAS"
else

	echo "$MESG_WAS_Location"
	read WAS_HOME
	checkDir "$WAS_HOME"

fi

EXEC="$WAS_HOME"/"$WSCP"
checkFile "$EXEC"
[ "${DEBUG}" = "ON" ] && echo "Executable: $EXEC"

#
# retrieve list of WAS nodes:
#
echo "$MESG_Retreiving_Available_WAS_Nodes"
local NODES=`echo "Node list" | "$EXEC" \
	| sed 's/wscp>//g' \
	| sed 's/^ //g' | sed 's/ $//g' \
	| sed 's/\///g'| sed 's/{//g' \
	| sed 's/}//g' | sed 's/Node://g'`

local ERROR=`echo "$NODES" | grep "invalid command name \"Node\""`
if [ ! "$ERROR" = "" ]; then
	echo "$NODES"
	echo "$MESG_ERROR_Perhaps_AdminServer_not_running"
	exit	
fi


if [ "$NODES" = "" ]; then

	[ "${DEBUG}" = "ON" ] && echo "Node list" | "$EXEC"

	echo "$MESG_No_Nodes_Error"
	exit

fi
echo $NODES

#
# pick first listed node as default
#
DEF_ADMINNODENAME=`echo "$NODES" | $AWK 'BEGIN{FS=" "}{print $1}'`

echo "$MESG_Enter_WAS_AdminNode [$DEF_ADMINNODENAME]"
read ADMINNODENAME
if [ "$ADMINNODENAME" = "" ]; then
	ADMINNODENAME="$DEF_ADMINNODENAME"
fi

##########################################################
#
# Run stop and delete scripts
#
##########################################################

cd "$DSY_PWD"
local XMLCfg="bin/XMLConfig.sh"
local EXEC="$WAS_HOME"/"$XMLCfg"
checkFile "$EXEC"


[ "${DEBUG}" = "ON" ] && echo "Executable: $EXEC"
"$EXEC" -adminNodeName $ADMINNODENAME -import ../common/dsy_was_stop.xml  -substitute "node=$ADMINNODENAME"
"$EXEC" -adminNodeName $ADMINNODENAME -import ../common/dsy_was_uninstall_module.xml  -substitute "node=$ADMINNODENAME"
"$EXEC" -adminNodeName $ADMINNODENAME -import ../common/dsy_was_uninstall.xml  -substitute "node=$ADMINNODENAME"
	
[ "${DEBUG}" = "ON" ] && echo "Uninstall server return: $?"
