#!/bin/ksh
# functions_install	This file contains functions to be used by most or all
#		shell scripts.
#
# Version:	06 June 2001
# Author:	Luis Alves <lalves@us.ibm.com>
# Changes:
#################################################################################

[ "${DEBUG}" = "ON" ] && echo "Executing functions_install"

[ "${DEBUG}" = "ON" ] && export MSG_PREFIX="[DB2EV]"
[ "${DEBUG}" = "ON" ] && export MSG_PREFIX_ERR="[DB2EV:ERR]"

checkIfDB2Instance(){
	local ISINSTANCE=`$DB2ILIST_CMD|grep $1`
#	# check for db2 instance
	if [ "{$ISINSTANCE}" = "" ]; then
		[ "$2" = "" ] && printErr "This user is not a DB2Instance. ($1)"
		printErr "$2"
		exit 1
	fi
}

checkDir() {
#	# check for directory
	if [ ! -d $1 ]; then
		[ "$2" = "" ] && printErr "Directory not Found. ($1)"
		printErr "$2"
		exit 1
	fi
}

checkGroup(){
	checkUserGRPS=`groups $1 | grep $2`
	if [ -z "$checkUserGRPS" ]; then
		[ "$3" = "" ] && printErr "Group not Found. ($3)"
		printErr "$3"
		exit 1
	fi
}

checkUser(){
#	# check for directory
	checkUserUSERNAME=`cat /etc/passwd|grep ^$1`
	if [ "${checkUserUSERNAME}" = "" ]; then
		[ "$2" = "" ] && printErr "User not Found. ($1)"
		printErr "$2"
		exit 1
	fi
}

checkFile() {
#	# check for directory
	if [ ! -f "$1" ]; then
		[ "$2" = "" ] && printErr "File not Found. ($1)"
		printErr "$2"
		exit 1
	fi
}

printMsg(){
	echo "$MSG_PREFIX $1"
}

printErr(){
	echo "$MSG_PREFIX_ERR $1"
}

copyFile() {
	oneLessLevelDir $2
	makeDir $LESSDIR_
	[ "${DEBUG}" = "ON" ] && printMsg "copyFile $1 -> $2"
	cp -f $1 $2
	if [ "$?" = "1" ]; then
		[ "$3" = "" ] && printErr "File not Found. ($1)"
		printErr "$3 ($1)"
		exit 1
	fi
}

makeDir(){
	mkdir -p $1
}

remDir(){
	[ "${DEBUG}" = "ON" ] && printMsg "Remove Dir ($1) ($2)"
#       # cannot put quotes on the $2 because it won't parse regular expresions		
	rm "$1" $2
	if [ "$?" = "1" ]; then
		[ "$3" = "" ] && printErr "Directory not Found. ($2)"
		printErr "$3 ($2)"
		exit 1
	fi
}

remFile(){
	[ "${DEBUG}" = "ON" ] && printMsg "Remove Files ($1) ($2)"
#       # cannot put quotes on the $2 because it won't parse regular expresions	
	rm $1 $2
	if [ "$?" = "1" ]; then
		[ "$3" = "" ] && printErr "Files not Found. ($2)"
		printErr "$3 ($2)"
		exit 1
	fi
}

remLink(){
	if [ -h "$1" ]; then
		[ "${DEBUG}" = "ON" ] && printMsg "removeLink $1"
#               # cannot put quotes on the $2 because it won't parse regular expresions	
		rm -f $1
		if [ "$?" = "1" ]; then
			printErr "Not able to remove link. ($1)"						
		fi
	else
		printErr "This is not a link cannot remove it. ($1)"				
	fi		
}


oneLessLevelDir(){
#	printMsg "4#$1#"
#	LESSDIR_=`echo $1|awk -F "/" 'BEGIN{i=2; res=""}{while(i < NF){res=res "/" $i; i++};} END{print res}'`
	LESSDIR_=`dirname "$1"`
}

# normal Copy
makeCopyDir() {
#	# printMsg "[$1],[$2],[$3]"
	checkDirCreate $2 "Not able to create Dir, check permissions."
	checkDir $1
	[ "${DEBUG}" = "ON" ] && printMsg "makeCopyDir $1 -> $2"
	
#	#if debug on print wrning messages to screen
	[ ! "${DEBUG}" = "ON" ] && cp -f $1/* $2 2>/dev/null
	[ "${DEBUG}" = "ON" ] && cp -f $1/* $2
	
#	# if [ "$?" = "1" ]; then
#	# 	[ "$4" = "" ] && printErr "Dir not Found. ($1)"
#	#	printErr "$4 ($1)"
#	#	exit 1
#	# fi
}

makeCopyDirRecur() {
	checkDirCreate $2 "Not able to create Dir, check permissions."
	[ "${DEBUG}" = "ON" ] && printMsg "makeCopyDirRecur $1 -> $2"
	cp -rf $1/* $2
	if [ "$?" = "1" ]; then
		[ "$4" = "" ] && printErr "Dir not Found. ($1)"
		printErr "$4 ($1)"
		exit 1
	fi
}

# Check for a Dir and Creates if
# checkDirCreate "$DIR"
checkDirCreate() {
#	# check for directory
	if [ ! -d $1 ]; then
		makeDir "$1"
		if [ "$?" = "1" ]; then
			[ "$2" = "" ] && printErr "Not able to create Dir, check permissions.($1)"
			printErr "$2 ($1)"
			exit 1
		fi
	fi
	checkDir "$1"
}

# lang func:
# Example getAvailableLang "$LANG_SUPPORTED_SOLARIS" "$DB2PATH/cc"
getAvailableLang () { # $1 supported lang, $2 where to look

	local SUPPORTEDLANGS=$1
	local PREVDIR="${PWD}"
	local INSTALL_UDB_LANG=
		
	cd "$2"
	
	for i in *; do
		for j in $SUPPORTEDLANGS; do
			if [ "${i}" = "${j}" ]; then
#				# [ "${DEBUG}" = "ON" ] && printMsg "Match [${i}]"
				INSTALL_UDB_LANG="${INSTALL_UDB_LANG} ${i}"
			fi
		done
	done

	cd "${PREVDIR}"
	export RETgetAvailableLang="${INSTALL_UDB_LANG}"
}

changeDSYSetId(){
 DSYID="`date -u +%m\-%d\-%Y/%H:%M:%S`"
 DSYID="`uname -n`/${DSYID}"
 DSYID=`echo $DSYID | awk '{print $1 $2 $3 $4 $5 $6 $7 $8 $9}'`
 export DSYID
 echo ### $DSYID

 cat "$DSYINSTDIR/Server/dsyctldb.sh" | awk '{if ($1=="." && $2=="dsysetid.sh") {print $1 " " $2 " \"'"$DSYID"'\"";}else{ print $0;}}' > "$DSYINSTDIR/Server/dsyctldb.sh.new"
 mv -f "$DSYINSTDIR/Server/dsyctldb.sh.new" "$DSYINSTDIR/Server/dsyctldb.sh"
}

logToFileBeginSection(){
	[ "${DEBUG}" = "ON" ] && printMsg "Log Begin Section ($1) to ($INSTALLLOGFILE)"
	if [ -f "$INSTALLLOGFILE" ]; then
		echo "# BEGIN SECTION $1" >> "$INSTALLLOGFILE"
	else
		printMsg "Error not able to find log file. ($INSTALLLOGFILE)"
	fi
}

logToFileEndSection(){
	[ "${DEBUG}" = "ON" ] && printMsg "Log End Section ($1) to ($INSTALLLOGFILE)"
	if [ -f "$INSTALLLOGFILE" ]; then
		echo "# END SECTION $1" >> "$INSTALLLOGFILE"
	else
		printMsg "Error not able to find log file. ($INSTALLLOGFILE)"
	fi
}

logToFile(){
	[ "${DEBUG}" = "ON" ] && printMsg "Log File ($1) to ($INSTALLLOGFILE)"
	if [ -f "$INSTALLLOGFILE" ]; then		
		echo "$1" >> "$INSTALLLOGFILE"
	else
		printMsg "Error not able to find log file. ($INSTALLLOGFILE)"
	fi
}

logToFileClean(){
	if [ -f "$INSTALLLOGFILE" ]; then
		rm -f "$INSTALLLOGFILE"
	fi
	[ "${DEBUG}" = "ON" ] && printMsg "Creating log file ($INSTALLLOGFILE)"
	oneLessLevelDir $INSTALLLOGFILE
	makeDir $LESSDIR_
	echo "# DB2Everyplace install log file " > "$INSTALLLOGFILE"
}

makeLink(){
	[ "${DEBUG}" = "ON" ] && printMsg "Link $1 -> $2"
	oneLessLevelDir "$2"
	checkDirCreate "$LESSDIR_" "Not able to create Dir, check permissions."
	if [ -d "$1" ]; then
		checkDir "$1"
	else
		checkFile "$1"
	fi
	
	if [ -h "$2" ]; then
		[ "${DEBUG}" = "ON" ] && printMsg "Remove Link ($2)"
		rm -f "$2"
	elif [ -d "$2" ] || [ -f "$2" ]; then
		[ "$4" = "" ] && printErr "This is not a link cannot remove it. ($2)"
		printErr "$4 ($2)"
		exit 1		
	fi
	ln -s "$1" "$2"
	if [ "$?" = "1" ]; then
		[ "$5" = "" ] && printErr "Not able to create link for some reason. ($1 -> $2)"
		printErr "$5 ($1)"
		exit 1
	fi
	logToFile $2
}

# returns the value of $MSG_yes or $MSG_no in ANSWER var
enterYesOrNo(){
	unset v_answer
	until [ "$v_answer" = "$MSG_yes" ] || [ "$v_answer" = "$MSG_no" ]; do
		print -n "$MSG_enter_yes_or_no [$MSG_y/$MSG_n]"
		read v_answer
		if [ "$v_answer" = "$MSG_y" ]; then
			v_answer="$MSG_yes"
		elif [ "$v_answer" = "$MSG_n" ]; then
			v_answer="$MSG_no"
		fi		
		print ""		
	done
	export ANSWER=$v_answer
}

permissionsDir(){	
	# oneLessLevelDir "$1"
	# checkDirCreate "$LESSDIR_" "Not able to create Dir, check permissions."	
	# PATH_=$LESSDIR_
	FILES_=$1
	USER_=$2
	GROUP_=$3
	PERMISSIONS_=$4
	
	CURDIR_=`pwd`
	
	[ "${DEBUG}" = "ON" ] && printMsg "Cur dir $CURDIR_, [$PATH_, $FILES_, $USER_, $GROUP_, $PERMISSIONS_]"	
	
	# cd "$PATH_"
	chown -hR $USER_ $FILES_/*
	chgrp -hR $GROUP_ $FILES_/*
	chmod -R $PERMISSIONS_ $FILES_/*
	cd "$CURDIR_"
}

permissions(){	
	# oneLessLevelDir "$1"
	# checkDirCreate "$LESSDIR_" "Not able to create Dir, check permissions."	
	# PATH_=$LESSDIR_
	FILES_=$1
	USER_=$2
	GROUP_=$3
	PERMISSIONS_=$4
	
	CURDIR_=`pwd`
	
	[ "${DEBUG}" = "ON" ] && printMsg "Cur dir $CURDIR_, [$PATH_, $FILES_, $USER_, $GROUP_, $PERMISSIONS_]"	
	
	# cd "$PATH_"
	chown -h $USER_ $FILES_
	chgrp -h $GROUP_ $FILES_
	chmod $PERMISSIONS_ $FILES_
	cd "$CURDIR_"
}

logNewDSYInstance(){
	DB2USERNAME_=$1
	USERGROUP_=$2
	DSYINSTDIR_=$3
	DSYHOME_=$4
	SYS_LANG_=$5
	echo "$DB2USERNAME_:$USERGROUP_:$DSYINSTDIR_:$DSYHOME_:$SYS_LANG_:" >> "$DSYINSTANCELOG"
}