
#!/bin/ksh
# functions_install_lang This file contains functions to be used by all
#		 shell scripts. language dependent
#
# Version:	06 June 2001
# Author:	Luis Alves <lalves@us.ibm.com>
# Changes:
#################################################################################

[ "${DEBUG}" = "ON" ] && echo "Executing functions_install_lang"

if [ "${MESG_100}" = "" ]; then
	export MESG_100="File not Found."
fi
if [ "${MESG_101}" = "" ]; then
	export MESG_101="Locale not supported."
fi
if [ "${MESG_102}" = "" ]; then
	export MESG_102="Unknown OS, please check OS var. values(AIX, Linux, or Solaris)"
fi

supportedLanguages(){
	if [ "$DSYOS" = "aix" ]; then
		export SUPPORTLANGS="$aix_locales"
	elif [ "$DSYOS" = "lin" ]; then
		export SUPPORTLANGS="$lin_locales"
	elif [ "$DSYOS" = "sol" ]; then
		export SUPPORTLANGS="$sol_locales"
	elif [ "$OS" = "win" ]; then
		export SUPPORTLANGS="$win_locales"
	else
		echo $MESG_102
		exit 1
	fi
}

# runFileLangEncoding $DSYOS $LANG $FILE
runFileLangEncoding(){
	local FILENAME=
#	# printMsg "##" $1 - $2 - $3
	local VAR=$2"_"$1"_txt_cp";
	echo "export LOADFILE=\$$VAR" > $DSY_INSTALL_TMP_DIR/loadmessagefile
	. $DSY_INSTALL_TMP_DIR/loadmessagefile
	checkFile "$DSY_INSTALL_DIR/install/$2/$LOADFILE/$3" "$MESG_100 ($DSY_INSTALL_DIR/install/$2/$LOADFILE/$3)"
	. $DSY_INSTALL_DIR/install/$2/$LOADFILE/$3
}

# runFileLang $DSYOS $LANG $FILE
runFileLang(){	
	checkFile "$DSY_INSTALL_DIR/install/$1/$2" "$MESG_100 ($DSY_INSTALL_DIR/install/$1/$2)"
	. $DSY_INSTALL_DIR/install/$1/$2
}

getLocale(){
	export RETgetLocale=""
	local LOCALLOCALE=$1
	local LOCALLOCALESTRING=$2
	local LOCALRETURN=$3
	[ "${DEBUG}" = "ON" ] &&  echo "##" $LOCALLOCALE - $LOCALLOCALESTRING - $LOCALRETURN
	for locale in $LOCALLOCALESTRING; do
		if [ "${locale}" = "$LOCALLOCALE" ]; then
			[ "${DEBUG}" = "ON" ] && printMsg "${locale} -> $LOCALRETURN"
			export RETgetLocale=$LOCALRETURN
		fi
	done
}

# example $DSYOS $DSY_LANG
getSYSLANG(){
	getLangRecord $1 "$DSYOS"
	export SYS_LANG=$RET_LANGSYS	
}

# getDSYLANG $LANG
getDSYLANG(){
	getLocale "$1" "$de_DE_compatible" "$de_DE_win"
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$De_DE_compatible" "$De_DE_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$en_US_compatible" "$en_US_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$es_ES_compatible" "$es_ES_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$Es_ES_compatible" "$Es_ES_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$it_IT_compatible" "$it_IT_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$It_IT_compatible" "$It_IT_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$fr_FR_compatible" "$fr_FR_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$Fr_FR_compatible" "$Fr_FR_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$ja_JP_compatible" "$ja_JP_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$Ja_JP_compatible" "$Ja_JP_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$ko_KR_compatible" "$ko_KR_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$zh_CN_compatible" "$zh_CN_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$zh_TW_compatible" "$zh_TW_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$Zh_TW_compatible" "$Zh_TW_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$ar_compatible" "$ar_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$cs_CZ_compatible" "$cs_CZ_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		getLocale "$1" "$iw_IL_compatible" "$iw_IL_win"
	fi
	if [ "${RETgetLocale}" = "" ]; then
		echo "$MESG_101 ($1)"
		exit 1
	fi
	export DSY_LANG=$RETgetLocale
}

# returns the code page but the locale as to be win or DSY locale
# example getCodePage "$WINLOCALE"
getCodePage(){
	getLangRecord $1 "$DSYOS"
}

# returns the code page but the locale as to be win or DSY locale
# example getLangRecord "$WINLOCALE" "$DSYOS"
getLangRecord(){
   [ "${DEBUG}" = "ON" ] && printMsg "locale tabble file $LOCALE_TABLE_DAT_FILE"
   local count=2000
   {      
      while [[ $count -gt 0 ]]; do
      (( count -= 1 ))
      
      read RET_OSNAME
      if [ "$?" = "1" ]; then
         printMsg "Code Page not Found ($1) in OS ($DSYOS)."
         exit 1
      fi
      read RET_LANGWIN
      read RET_LANGDSY
      read RET_LANGSYS
      read RET_LANGCOMPAT
      read RET_CODEPAGE
      read blankline
      if [ "$RET_OSNAME" = "$2" ] && [ "$RET_LANGWIN" = "$1" ]; then
      		[ "${DEBUG}" = "ON" ] && printMsg "[$2,$1][$RET_OSNAME,$RET_LANGWIN,$RET_LANGDSY,$RET_LANGSYS,$RET_LANGCOMPAT,$RET_CODEPAGE]"      		
   		return
      fi
      done
   } < "$LOCALE_TABLE_DAT_FILE"
}

# Exec cmd from lang directories XX style to YY style
# example  ExecCmdLangEncodingXX2YY $command $DIR1 $dsy_locales  $DIRDEST  $win_locales silent
#          ExecCmdLangEncodingXX2YY "makeCopyDir" "$1" "$dsy_locales" "$2" "$win_locales" 
ExecCmdLangRemoveEncodingXX2YY() {
#       params	
	local CMD=$1
	local DIRORIG=$2
	local LOCALESORIG=$3
	local DIRDEST=$4
	local LOCALESDEST=$5	
	local MODE=$7
	
	local temp=$LOCALESDEST
	for origLocale in $LOCALESORIG; do
		local newtemp=""
		local first="True"
		for locale in $temp; do
			if [ $first = "True" ]; then
				destLocale=$locale;
				first="False"
			else
				newtemp="$newtemp $locale"
			fi			
		done
		temp=$newtemp
		
		getCodePage "$origLocale"		
		local codePage=$RET_CODEPAGE
		[ "${DEBUG}" = "ON" ] && printMsg "$CMD $DIRORIG/$origLocale/$codePage $DIRDEST/$destLocale $MODE"
		$CMD "$DIRORIG/$origLocale/$codePage" "$DIRDEST/$destLocale" $MODE		
	done		
}

# Exec cmd from lang directories XX style to YY style
# example  ExecCmdLangXX2YY $command $DIR1 $dsy_locales  $DIRDEST  $win_locales silent
#          ExecCmdLangXX2YY "makeCopyDir" "$1" "$dsy_locales" "$2" "$win_locales" 
#          ExecCmdLangXX2YY "makeCopyDir" "$1" "$dsy_locales" "$2" "$win_locales" silent "CONCAT"
ExecCmdLangXX2YY() {
#       params	
	local CMD=$1
	local DIRORIG=$2
	local LOCALESORIG=$3
	local DIRDEST=$4
	local LOCALESDEST=$5	
	local MODE=$6
	local CATMODE=$7
	
#	echo $CMD - $DIRORIG - $LOCALESORIG - $DIRDEST - $LOCALESDEST - $CATMODE - $MODE
	
	local temp=$LOCALESDEST
	for origLocale in $LOCALESORIG; do
		local newtemp=""
		local first="True"
		for locale in $temp; do
			if [ $first = "True" ]; then
				destLocale=$locale;
				first="False"
			else
				newtemp="$newtemp $locale"
			fi			
		done
		temp=$newtemp
		
		
		if [ "${CATMODE}" = "CONCAT" ]; then
			export CUR_S_LOCALE=$origLocale
			export CUR_D_LOCALE=$destLocale
			DIRORIGTMP=`eval echo $DIRORIG`
			DIRDESTTMP=`eval echo $DIRDEST`
			[ "${DEBUG}" = "ON" ] && printMsg "$CMD $DIRORIGTMP $DIRDESTTMP ($MODE)"
			$CMD "$DIRORIGTMP" "$DIRDESTTMP" $MODE
		else
			[ "${DEBUG}" = "ON" ] && printMsg "$CMD $DIRORIG/$origLocale $DIRDEST/$destLocale ($MODE)"
			$CMD "$DIRORIG/$origLocale" "$DIRDEST/$destLocale" $MODE
		fi
	done		
}

#Example : makeLinkSelectedLangSpecial "$SOURCE" "$DESTDIR "$UDB_DETECT_LANG"
makeLinkSelectedLangSpecial(){
#	# checkDirCreate $2 "Not able to create Dir, check permissions."
	[ "${DEBUG}" = "ON" ] && printMsg "Link $1 -> $2 ($UDB_DETECT_LANG)"
	ExecCmdLangXX2YY "makeLink" "$1" "$3" "$2" "$3" "silent" "CONCAT"
}

# same as below but with support for encoding
makeCopyDirLangEncodingWIN2XXX(){
	checkDirCreate $2 "Not able to create Dir, check permissions."
	[ "${DEBUG}" = "ON" ] && printMsg "Copy $1 -> $2"
	
	if [ "$DSYOS" = "aix" ]; then
		ExecCmdLangRemoveEncodingXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$aix_locales"  silent
	elif [ "$DSYOS" = "lin" ]; then
		ExecCmdLangRemoveEncodingXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$lin_locales"  silent
	elif [ "$DSYOS" = "sol" ]; then
		ExecCmdLangRemoveEncodingXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$sol_locales"  silent
	elif [ "$OS" = "win" ]; then
		ExecCmdLangRemoveEncodingXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$win_locales"  silent
	else
		echo $MESG_102
		exit 1
	fi
}


# Copy from lang directories WIN style to SOME OS STYLE
# this function use $DSYOS to know witch OS is running
makeCopyDirLangWIN2XXX() {
	checkDirCreate $2 "Not able to create Dir, check permissions."
	[ "${DEBUG}" = "ON" ] && printMsg "makeCopyDirLangWIN2XXX $1 -> $2"
	
	if [ "$DSYOS" = "aix" ]; then
		ExecCmdLangXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$aix_locales"  silent
	elif [ "$DSYOS" = "lin" ]; then
		ExecCmdLangXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$lin_locales"  silent
	elif [ "$DSYOS" = "sol" ]; then
		ExecCmdLangXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$sol_locales"  silent
	elif [ "$OS" = "win" ]; then
		ExecCmdLangXX2YY "makeCopyDir" "$1" "$win_locales" "$2" "$win_locales"  silent
	else
		echo $MESG_102
		exit 1
	fi
}

makeLinkLangXXX(){
	oneLessLevelDir "$2"
	checkDirCreate "$LESSDIR_" "Not able to create Dir, check permissions."
	rm -f "$2"	
	checkDir "$1/$SYS_LANG"
	ln -s "$1/$SYS_LANG" "$2"
}

makeCopyDirLangXXX(){
	checkDirCreate $2 "Not able to create Dir, check permissions."
	[ "${DEBUG}" = "ON" ] && printMsg "makeCopyDirLangXXX $1 -> $2"
	makeCopyDir "$1/$SYS_LANG" "$2"			
}