#!/bin/ksh
# update_dsy_env_vars	This file sets up the enveriment var need for config
#
# Version:	06 June 2001
# Changes:
#################################################################################
[ "${DEBUG}" = "ON" ] && echo "Executing update_dsy_env_vars"

if [ "${MESG_102}" = "" ]; then
	export MESG_102="Unknown OS, please check OS var. values(AIX, Linux, or Solaris)"
fi

OS=`uname -s`

if [ "$OS" = "AIX" ] || [ "$OS" = "Aix" ]; then
	export DSYOS="aix"
elif [ "$OS" = "LINUX" ] || [ "$OS" = "Linux" ]; then
	export DSYOS="lin"
elif [ "$OS" = "SOLARIS" ] || [ "$OS" = "Solaris" ] || [ "$OS" = "SunOS" ]; then
	export DSYOS="sol"
elif [ "$OS" = "WIN" ] || [ "$OS" = "Win" ]; then
	export DSYOS="win"
else
	echo $MESG_102
fi

# update enviroment vars
unset CLASSPATH

if [ ! -d "$DB2PATH" ]; then
#	# check for udb instalation dir
	if [ "$DSYOS" = "aix" ]; then
	    DB2PATH=/usr/lpp/db2_07_01
	  elif [ "$DSYOS" = "lin" ]; then
	    DB2PATH=/usr/IBMdb2/V7.1
	  elif [ "$DSYOS" = "sol" ]; then
	    DB2PATH=/opt/IBMdb2/V7.1
	  else
	    DB2PATH=/opt/IBMdb2/V7.1
	fi
	
	if [ ! -d "$DB2PATH" ]; then
		if [ -d $HOME/sqllib ]; then
		  DB2PATH=$HOME/sqllib
		elif [ -n "$DB2DIR" ]; then
		  DB2PATH=$DB2DIR
		else
			echo "***Cannot find a suitable DB2PATH, exiting."
	  		exit 1
		fi
	fi
fi

[ "${DEBUG}" = "ON" ] && printMsg "DB2PATH=$DB2PATH"

# define default instalation directory
if [ "${DSYOS}" = "lin" ]; then 
	ROOT_DSYHOME=/opt/DB2Everyplace72
elif [ "${DSYOS}" = "aix" ]; then
	ROOT_DSYHOME=/usr/lpp/DB2Everyplace72
elif [ "${DSYOS}" = "sol" ]; then
	ROOT_DSYHOME=/opt/DB2Everyplace72
else
	ROOT_DSYHOME=/usr/DB2Everyplace72
fi

#Default language, root, and root group
if [ "${DSYOS}" = "lin" ]; then 
	DSY_LANG_DEFAULT=en_US
	ROOTUSER=root
	ROOTGROUP=root
elif [ "${DSYOS}" = "aix" ]; then
	DSY_LANG_DEFAULT=en_US
	ROOTUSER=root
	ROOTGROUP=system
elif [ "${DSYOS}" = "sol" ]; then
	DSY_LANG_DEFAULT=en_US
	ROOTUSER=root
	ROOTGROUP=root
else
	DSY_LANG_DEFAULT=en_US
	ROOTUSER=root
	ROOTGROUP=root
fi

# get install dir
local BINDDIR=`dirname $0`
export DSY_INSTALL_DIR=`cd "$BINDDIR/..";pwd`
[ "${DEBUG}" = "ON" ] && printMsg "INSTALLSOURCES=$DSY_INSTALL_DIR"

# setting up temp dir
export DSY_INSTALL_TMP_DIR="$DSY_INSTALL_DIR/temp"
checkDirCreate "$DSY_INSTALL_TMP_DIR"

# table with locales
LOCALE_TABLE_DAT_FILE="$DSY_INSTALL_DIR/install/locale_table.dat"

# Setup Locale $DSY_LANG
if [ "${LANG}" = "" ]; then
   [ "${DEBUG}" = "ON" ] && echo "***LANG not set.  Using American English..."   
   export DSY_LANG=$DSY_LANG_DEFAULT
else
# check if support Locale
   getDSYLANG $LANG
fi

# Setup Locale $SYS_LANG
getSYSLANG $DSY_LANG

# Check to see if GREP has been defined...
if [ "$GREP" = "" ]; then
	export GREP="/bin/grep"
	if [ ! -f "$GREP" ]; then
		export GREP="/sbin/grep"
		if [ ! -f "$GREP" ]; then
			export GREP="/usr/bin/grep"			
		fi
	fi
fi

checkFile $GREP "Comand not found. ($GREP)"

# Check to see if AWK has been defined...
if [ "$AWK" = "" ]; then
	export AWK="/bin/awk"
	if [ ! -f "$AWK" ]; then
		export AWK="/sbin/awk"
		if [ ! -f "$AWK" ]; then
			export AWK="/usr/bin/awk"
		fi
	fi
fi

checkFile $AWK "Comand not found. ($AWK)"

# i have to auto detect languages

# get value for SUPPORTLANGS under this OS
supportedLanguages

# get value for installed languages under this DB2 Instalation
getAvailableLang "$SUPPORTLANGS" "$DB2PATH/cc"
export UDB_DETECT_LANG=$RETgetAvailableLang
[ "${DEBUG}" = "ON" ] && echo "DB2 languages detected ($UDB_DETECT_LANG)"


# log file place
export INSTALLLOGFILE=$ROOT_DSYHOME/install/install_files.log

# file generated by setup with all instalation variables
INSTALL_VARS_FILE="$ROOT_DSYHOME/install/dsy_setenv.sh"

# home directory:
if [ -f "$DB2PATH/bin/db2ilist" ]; then
	DB2ILIST_CMD="$DB2PATH/bin/db2ilist"
elif [ -f "$DB2PATH/instance/db2ilist" ]; then
	DB2ILIST_CMD="$DB2PATH/instance/db2ilist"
fi

DSYVERSIONFILE="$DSY_INSTALL_DIR/install/dsyversion.dat"
DSYVERSION=`cat  "$DSYVERSIONFILE"`

# file with instance instalations
DSYINSTANCELOG="$ROOT_DSYHOME/install/dsyinstance.log"

# true if this is fixpack version
ISFIXPACK="FALSE"
